# Bu araç @keyiflerolsun tarafından | @KekikAkademi için yazılmıştır.

from contextlib import suppress
from BTKSorgu   import KekikGUI
from tkinter    import ttk
from BTKSorgu   import BTKSorgu

kekik = KekikGUI(
    pencere_adi = "BTK Sorgu",
    logo_yolu   = "logo.png",
    satir_sutun = 1,
    ortala      = False,
    cikis_onay  = False,
    p_genislik  = 400,
    p_yukseklik = 250
)

def input_alanlari():
    # İnput Alanları için bir Çerçeve oluşturun
    kekik.pencere.inputlar_frame = ttk.Frame(kekik.pencere, padding=(0, 0, 0, 10))
    kekik.pencere.inputlar_frame.grid(row=0, column=0, padx=(20, 0), pady=(20, 0), sticky="nsew")
    kekik.pencere.inputlar_frame.columnconfigure(index=0, weight=1)

    # Giriş Alanı
    kekik.pencere.arama_metni = ttk.Entry(kekik.pencere.inputlar_frame)
    kekik.pencere.arama_metni.insert(0, "Sorgulanacak Domain Giriniz..")
    kekik.pencere.arama_metni.bind("<Return>", lambda _: ara_buton_tiklaninca())
    kekik.pencere.arama_metni.state(["invalid"])
    kekik.pencere.arama_metni.grid(row=0, column=0, padx=(10, 10), pady=(10, 10), sticky="ew")
    kekik.pencere.arama_metni.focus()

    # Ekle Buton
    kekik.pencere.ara_buton = ttk.Button(kekik.pencere.inputlar_frame, text="Ara", command=lambda: ara_buton_tiklaninca())
    kekik.pencere.ara_buton.grid(row=1, column=0, padx=(10, 10), pady=10, sticky="ew")

    # Ayırıcı
    kekik.pencere.ayrac = ttk.Separator(kekik.pencere.inputlar_frame)
    kekik.pencere.ayrac.grid(row=2, column=0, padx=(10, 10), pady=10, sticky="ew")

def ara_buton_tiklaninca():
    arama_sorgusu = kekik.pencere.arama_metni.get()
    kekik.pencere.arama_metni.state(["!invalid"])

    kekik.pencere.cikti_frame = ttk.Frame(kekik.pencere, padding=(0, 0, 0, 10))
    kekik.pencere.cikti_frame.grid(row=1, column=0, sticky="n")
    kekik.pencere.cikti_frame.columnconfigure(index=0, weight=1)
    kekik.pencere.cikti_frame.rowconfigure(index=0, weight=1)

    with suppress(Exception):
        kekik.pencere._bekleyiniz.destroy()

    kekik.pencere._bekleyiniz = ttk.Label(kekik.pencere.inputlar_frame, text="Lütfen Bekleyiniz...", wraplength=kekik.p_genislik - 40)
    kekik.pencere._bekleyiniz.configure(foreground="#17a2b8", justify="center")
    kekik.pencere._bekleyiniz.grid(row=3, column=0, pady=(10, 0), sticky="n")

    kekik.pencere.update()

    kekik.pencere._bekleyiniz.configure(text=f"Lütfen Bekleyiniz!\n\n{arama_sorgusu} Aranıyor..")
    kekik.pencere.update()

    btk = str(BTKSorgu(arama_sorgusu))
    kekik.pencere._bekleyiniz.configure(text=btk)

    kekik.pencere.update()

    kekik.pencere.arama_metni.focus()

def basla():
    input_alanlari()
    kekik.mainloop()


# Bu araç @keyiflerolsun tarafından | @KekikAkademi için yazılmıştır.

import tkinter as tk
from tkinter import messagebox
from tkinter import ttk
from base64  import encodebytes
from sv_ttk  import set_theme

class KekikGUI(tk.Tk):
    def __init__(self, pencere_adi:str="keyiflerolsun GUI", logo_yolu:str="logo.png", satir_sutun:int=1, ortala:bool=True, cikis_onay:bool=True, p_genislik=400, p_yukseklik=300):
        super().__init__()
        set_theme("dark")
        self.title(pencere_adi)
        self.cikis_onay = cikis_onay

        # ? Pencere Kapanmadan Önce Fonksiyon Tetiklemek
        self.protocol("WM_DELETE_WINDOW", self.pencereyi_kapat)

        # ? Pencere Özellikleri
        self.bind("<Escape>",    lambda event: self.pencereyi_kapat()) # * ESC ile çıkış
        self.bind("<F11>",       lambda event: self.tam_ekran())       # * Tam Ekran
        self.bind("<Control-a>", lambda event: self.ctrl_a(event))

        # ? Pencere İkonu
        logo_b64 = encodebytes(open(logo_yolu, "rb").read())
        favicon  = tk.PhotoImage(data=logo_b64)
        self.iconphoto(False, favicon)

        # ? Pencere için bir minimum boyut ayarlayın ve ortasına yerleştirin
        self.update()
        self.p_genislik  = max(self.winfo_width(), p_genislik)
        self.p_yukseklik = max(self.winfo_height(), p_yukseklik)
        self.minsize(self.p_genislik, self.p_yukseklik)
        if ortala:
            x_kordinat = int((self.winfo_screenwidth()  / 2) - (self.p_genislik  / 2))
            y_kordinat = int((self.winfo_screenheight() / 2) - (self.p_yukseklik / 2))
            self.geometry(f"+{x_kordinat}+{y_kordinat - 20}")

        self.pencere = ttk.Frame(self)
        self.pencere.pack(fill="both", expand=True)

        # ? Uygulamayı Responsive Hale Getirin
        for index in range(satir_sutun):  # * 1 Satır 1 Sütun
            self.pencere.columnconfigure(index=index, weight=1)
            self.pencere.rowconfigure(index=index, weight=1)

        # ? Sağ Alt Köşeye Yeniden Boyutlandırma
        self.sizegrip = ttk.Sizegrip(self.pencere)
        self.sizegrip.grid(row=100, column=100, padx=(0, 5), pady=(0, 5))
        self.update()

    def tam_ekran(self):
        self.attributes("-fullscreen", not self.attributes("-fullscreen"))

        if self.attributes("-fullscreen"):
            self.sizegrip.grid(row=100, column=100, padx=(0, 5), pady=(0, 5))        
        else:
            self.sizegrip.grid_forget()

    def ctrl_a(self, event):
        event.widget.select_range(0, "end")
        event.widget.icursor("end")

    def pencereyi_kapat(self):
        if (
            self.cikis_onay and messagebox.askokcancel("Program Kapanıyor", "Bunu Yapmak İstediğine Emin Misin?")
            or not self.cikis_onay
        ):
            self.destroy()